@@ -48,6 +48,7 @@ sub new {
     ssh_ip                 => undef,
     ssh_port               => undef,
     ssh_check_command      => undef,
+    ssh_connection_timeout => undef,
     workdir                => undef,
     status_handler         => undef,
     secondary_check_script => undef,
@@ -290,13 +291,15 @@ sub ssh_check {
   my $ssh_user_host       = $ssh_user . '@' . $ssh_ip;
   my $rc                  = 1;
   eval {
-    if ( my $pid = fork )
-    {
+    if ( my $pid = fork ) {
       local $SIG{ALRM} = sub {
         kill 9, $pid;
         waitpid( $pid, 0 );
         die "Got timeout on checking SSH connection to $ssh_host!";
       };
+      $log->debug(
+"SSH connection test to $ssh_host, option $MHA::ManagerConst::SSH_OPT_CHECK, timeout $num_secs_to_timeout"
+      );
       alarm $num_secs_to_timeout;
       waitpid( $pid, 0 );
       alarm 0;
@@ -429,7 +432,7 @@ sub invoke_ssh_check {
       exit ssh_check(
         $self->{ssh_user}, $self->{ssh_host},
         $self->{ssh_ip},   $self->{ssh_port},
-        $self->{logger},   $self->{interval} * 3,
+        $self->{logger},   $self->{ssh_connection_timeout},
         $self->{ssh_check_command}
       );
     }
@@ -444,8 +447,7 @@ sub is_secondary_down {
   my $log            = $self->{logger};
   my $master_is_down = 0;
   eval {
-    if ( $self->{_sec_check_invoked} )
-    {
+    if ( $self->{_sec_check_invoked} ) {
       waitpid( $self->{_sec_check_pid}, 0 );
       my $sec_check_exit_code = $?;
       $self->{_sec_check_invoked} = 0;
@@ -474,8 +476,7 @@ sub is_ssh_reachable {
   my $log           = $self->{logger};
   my $ssh_reachable = 2;
   eval {
-    if ( $self->{_ssh_check_invoked} )
-    {
+    if ( $self->{_ssh_check_invoked} ) {
       waitpid( $self->{_ssh_check_pid}, 0 );
       my $ssh_check_exit_code = $?;
       $self->{_ssh_check_invoked} = 0;
@@ -572,16 +573,15 @@ sub wait_until_unreachable($) {
   my $master_is_down = 0;
 
   eval {
-    while (1)
-    {
+    while (1) {
       $self->{_tstart} = [gettimeofday];
       if ( $self->{_need_reconnect} ) {
         my ( $rc, $mysql_err ) = $self->connect();
         if ($rc) {
           if ($mysql_err) {
             if (
-              grep ( $_ == $mysql_err, @MHA::ManagerConst::ALIVE_ERROR_CODES ) >
-              0 )
+              grep ( $_ == $mysql_err, @MHA::ManagerConst::ALIVE_ERROR_CODES )
+              > 0 )
             {
               $log->info(
 "Got MySQL error $mysql_err, but this is not mysql crash. Continue health check.."
@@ -651,8 +651,7 @@ sub wait_until_unreachable($) {
 
         # Child process
         eval {
-          if ( $self->{ping_type} eq $MHA::ManagerConst::PING_TYPE_CONNECT )
-          {
+          if ( $self->{ping_type} eq $MHA::ManagerConst::PING_TYPE_CONNECT ) {
             exit $self->ping_connect();
           }
           elsif ( $self->{ping_type} eq $MHA::ManagerConst::PING_TYPE_SELECT ) {
