@@ -51,6 +51,8 @@ my $g_wait_on_failover_error = 0;
 my $g_ignore_last_failover;
 my $g_skip_save_master_binlog;
 my $g_remove_dead_master_conf;
+my $g_skip_change_master;
+my $g_skip_disable_read_only;
 my $_real_ssh_reachable;
 my $_saved_file_suffix;
 my $_start_datetime;
@@ -155,8 +157,8 @@ sub check_settings($) {
   if (
     !(
          $_dead_master_arg{hostname} eq $m->{hostname}
-      && $_dead_master_arg{ip}       eq $m->{ip}
-      && $_dead_master_arg{port}     eq $m->{port}
+      && $_dead_master_arg{ip} eq $m->{ip}
+      && $_dead_master_arg{port} eq $m->{port}
     )
     )
   {
@@ -233,14 +235,15 @@ sub check_settings($) {
 
     # Master_Host is either hostname or IP address of the current master
     if ( $dead_master->{hostname} ne $slave->{Master_Host}
-      && $dead_master->{ip}       ne $slave->{Master_Host}
+      && $dead_master->{ip} ne $slave->{Master_Host}
       && $dead_master->{hostname} ne $slave->{Master_IP}
-      && $dead_master->{ip}       ne $slave->{Master_IP} )
+      && $dead_master->{ip} ne $slave->{Master_IP} )
     {
       $log->error(
         sprintf(
           "Slave %s does not replicate from dead master %s. Stop failover.",
-          $slave->get_hostinfo(), $dead_master->get_hostinfo()
+          $slave->get_hostinfo(),
+          $dead_master->get_hostinfo()
         )
       );
       croak;
@@ -458,7 +461,7 @@ sub force_shutdown($) {
       MHA::HealthCheck::ssh_check_simple(
         $dead_master->{ssh_user}, $dead_master->{ssh_host},
         $dead_master->{ssh_ip},   $dead_master->{ssh_port},
-        $dead_master->{logger},   5
+        $dead_master->{logger},   $dead_master->{ssh_connection_timeout}
       )
       )
     {
@@ -1135,7 +1138,7 @@ sub apply_diff {
 "Connecting to the target slave host $target->{hostname}, running recover script.."
   );
   my $command =
-"apply_diff_relay_logs --command=apply --slave_user=$target->{user} --slave_host=$target->{hostname} --slave_ip=$target->{ip}  --slave_port=$target->{port} --apply_files=$diff_files --workdir=$target->{remote_workdir} --target_version=$target->{mysql_version} --timestamp=$_start_datetime --handle_raw_binlog=$target->{handle_raw_binlog} --disable_log_bin=$target->{disable_log_bin} --manager_version=$MHA::ManagerConst::VERSION";
+"apply_diff_relay_logs --command=apply --slave_user=$target->{escaped_user} --slave_host=$target->{hostname} --slave_ip=$target->{ip}  --slave_port=$target->{port} --apply_files=$diff_files --workdir=$target->{remote_workdir} --target_version=$target->{mysql_version} --timestamp=$_start_datetime --handle_raw_binlog=$target->{handle_raw_binlog} --disable_log_bin=$target->{disable_log_bin} --manager_version=$MHA::ManagerConst::VERSION";
   if ( $target->{log_level} eq "debug" ) {
     $command .= " --debug ";
   }
@@ -1143,8 +1146,8 @@ sub apply_diff {
     $command .= " --ssh_options='$MHA::NodeConst::SSH_OPT_ALIVE' ";
   }
   $logger->info("Executing command: $command --slave_pass=xxx");
-  if ( $target->{password} ne "" ) {
-    $command .= " --slave_pass=$target->{password} ";
+  if ( $target->{escaped_password} ne "" ) {
+    $command .= " --slave_pass=$target->{escaped_password} ";
   }
   $target->check_set_ssh_status( $logger, 1 ) if ( $target->{ssh_ok} >= 2 );
   if ( $target->{ssh_ok} == 0 ) {
@@ -1241,7 +1244,7 @@ sub recover_master($$$) {
 
   if ( $new_master->{master_ip_failover_script} ) {
     my $command =
-"$new_master->{master_ip_failover_script} --command=start --ssh_user=$new_master->{ssh_user} --orig_master_host=$dead_master->{hostname} --orig_master_ip=$dead_master->{ip} --orig_master_port=$dead_master->{port} --new_master_host=$new_master->{hostname} --new_master_ip=$new_master->{ip} --new_master_port=$new_master->{port}";
+"$new_master->{master_ip_failover_script} --command=start --ssh_user=$new_master->{ssh_user} --orig_master_host=$dead_master->{hostname} --orig_master_ip=$dead_master->{ip} --orig_master_port=$dead_master->{port} --new_master_host=$new_master->{hostname} --new_master_ip=$new_master->{ip} --new_master_port=$new_master->{port} --new_master_user=$new_master->{escaped_user} --new_master_password=$new_master->{escaped_password}";
     $command .=
       $dead_master->get_ssh_args_if( 1, "orig", $_real_ssh_reachable );
     $command .= $new_master->get_ssh_args_if( 2, "new", 1 );
@@ -1273,7 +1276,9 @@ sub recover_master($$$) {
   }
 
   # Allow write access on master (if read_only==1)
-  $new_master->disable_read_only();
+  unless ($g_skip_disable_read_only) {
+    $new_master->disable_read_only();
+  }
 
   $log->info("** Finished master recovery successfully.");
   $mail_subject .= " to $new_master->{hostname}";
@@ -1332,6 +1337,14 @@ sub recover_slaves_internal {
         $mail_body .=
 "$target->{hostname}: OK: Applying all logs succeeded. Slave started, replicating from $new_master->{hostname}.\n";
       }
+      elsif ( $exit_code == 10 ) {
+        $target->{recover_ok} = 1;
+        $log->info(
+          sprintf( "-- Slave recovery on host %s succeeded.",
+            $target->get_hostinfo() )
+        );
+        $mail_body .= "$target->{hostname}: OK: Applying all logs succeeded.\n";
+      }
       elsif ( $exit_code == 20 ) {
         $skipping = 1;
         $log->info(
@@ -1404,6 +1417,10 @@ sub recover_slaves_internal {
       if ( recover_slave( $target, $pplog ) ) {
         $pm->finish(1);
       }
+      if ($g_skip_change_master) {
+        $pplog->info("Skipping change master and start slave");
+        $pm->finish(10);
+      }
       if (
         $_server_manager->change_master_and_start_slave(
           $target, $new_master, $master_log_file, $master_log_pos, $pplog
@@ -1497,23 +1514,30 @@ sub recover_slaves($$$$$) {
     $latest_base_slave );
   my $reset_slave_rc;
   if ( $recover_slave_rc == 0 ) {
-    $log->info("All new slave servers recovered successfully.");
-    $log->info();
-    $log->info("* Phase 5: New master cleanup phease..");
-    $log->info();
-    if ( $new_master->{skip_reset_slave} ) {
-      $log->info("Skipping RESET SLAVE on the new master.");
-      $reset_slave_rc = 0;
+    if ($g_skip_change_master) {
+      $log->info("All slave servers are applied logs successfully.");
+      $log->info();
     }
     else {
-      $log->info("Resetting slave info on the new master..");
-      $reset_slave_rc = $new_master->reset_slave_on_new_master();
-      if ( $reset_slave_rc eq '0' ) {
-        $mail_body .=
-          "$new_master->{hostname}: Resetting slave info succeeded.\n";
+      $log->info("All new slave servers recovered successfully.");
+      $log->info();
+      $log->info("* Phase 5: New master cleanup phase..");
+      $log->info();
+      if ( $new_master->{skip_reset_slave} ) {
+        $log->info("Skipping RESET SLAVE on the new master.");
+        $reset_slave_rc = 0;
       }
       else {
-        $mail_body .= "$new_master->{hostname}: Resetting slave info failed.\n";
+        $log->info("Resetting slave info on the new master..");
+        $reset_slave_rc = $new_master->reset_slave_on_new_master();
+        if ( $reset_slave_rc eq '0' ) {
+          $mail_body .=
+            "$new_master->{hostname}: Resetting slave info succeeded.\n";
+        }
+        else {
+          $mail_body .=
+            "$new_master->{hostname}: Resetting slave info failed.\n";
+        }
       }
     }
   }
@@ -1725,6 +1749,8 @@ sub main {
     'skip_save_master_binlog'  => \$g_skip_save_master_binlog,
     'remove_dead_master_conf'  => \$g_remove_dead_master_conf,
     'remove_orig_master_conf'  => \$g_remove_dead_master_conf,
+    'skip_change_master'       => \$g_skip_change_master,
+    'skip_disable_read_only'   => \$g_skip_disable_read_only,
   );
   setpgrp( 0, $$ ) unless ($g_interactive);
 
