@@ -48,6 +48,7 @@ my $g_interactive = 1;
 my $g_logfile;
 my $g_wait_on_monitor_error = 0;
 my $g_skip_ssh_check;
+my $g_ignore_fail_on_start = 0;
 my $_master_node_version;
 my $_server_manager;
 my $RETRY = 100;
@@ -113,8 +114,9 @@ sub check_master_ssh_env($) {
   my $ssh_reachable;
   if (
     MHA::HealthCheck::ssh_check_simple(
-      $target->{ssh_user}, $target->{ssh_host}, $target->{ssh_ip},
-      $target->{ssh_port}, $target->{logger},   5
+      $target->{ssh_user}, $target->{ssh_host},
+      $target->{ssh_ip},   $target->{ssh_port},
+      $target->{logger},   $target->{ssh_connection_timeout}
     )
     )
   {
@@ -164,7 +166,7 @@ sub check_slave_env() {
   foreach my $s (@alive_servers) {
     my $ssh_user_host = $s->{ssh_user} . '@' . $s->{ssh_ip};
     my $command =
-"apply_diff_relay_logs --command=test --slave_user=$s->{user} --slave_host=$s->{hostname} --slave_ip=$s->{ip} --slave_port=$s->{port} --workdir=$s->{remote_workdir} --target_version=$s->{mysql_version} --manager_version=$MHA::ManagerConst::VERSION";
+"apply_diff_relay_logs --command=test --slave_user=$s->{escaped_user} --slave_host=$s->{hostname} --slave_ip=$s->{ip} --slave_port=$s->{port} --workdir=$s->{remote_workdir} --target_version=$s->{mysql_version} --manager_version=$MHA::ManagerConst::VERSION";
     if ( $s->{relay_log_info_type} eq "TABLE" ) {
       $command .=
 " --relay_dir=$s->{relay_dir} --current_relay_log=$s->{current_relay_log} ";
@@ -181,8 +183,8 @@ sub check_slave_env() {
     }
     $log->info("  Executing command : $command --slave_pass=xxx");
 
-    if ( $s->{password} ne "" ) {
-      $command .= " --slave_pass=$s->{password}";
+    if ( $s->{escaped_password} ne "" ) {
+      $command .= " --slave_pass=$s->{escaped_password}";
     }
     $log->info(
       "  Connecting to $ssh_user_host($s->{ssh_host}:$s->{ssh_port}).. ");
@@ -358,7 +360,8 @@ sub wait_until_master_is_unreachable() {
         sprintf( "Identified master is %s.", $current_master->get_hostinfo() )
       );
     }
-    $_server_manager->validate_num_alive_servers( $current_master, 0 );
+    $_server_manager->validate_num_alive_servers( $current_master,
+      $g_ignore_fail_on_start );
     if ( check_master_ssh_env($current_master) ) {
       if ( check_master_binlog($current_master) ) {
         $log->error("Master configuration failed.");
@@ -400,22 +403,23 @@ sub wait_until_master_is_unreachable() {
     $log->debug("SSH check command: $ssh_check_command");
 
     $master_ping = new MHA::HealthCheck(
-      user              => $current_master->{user},
-      password          => $current_master->{password},
-      ip                => $current_master->{ip},
-      hostname          => $current_master->{hostname},
-      port              => $current_master->{port},
-      interval          => $current_master->{ping_interval},
-      ssh_user          => $current_master->{ssh_user},
-      ssh_host          => $current_master->{ssh_host},
-      ssh_ip            => $current_master->{ssh_ip},
-      ssh_port          => $current_master->{ssh_port},
-      ssh_check_command => $ssh_check_command,
-      status_handler    => $_status_handler,
-      logger            => $log,
-      logfile           => $g_logfile,
-      workdir           => $g_workdir,
-      ping_type         => $current_master->{ping_type},
+      user                   => $current_master->{user},
+      password               => $current_master->{password},
+      ip                     => $current_master->{ip},
+      hostname               => $current_master->{hostname},
+      port                   => $current_master->{port},
+      interval               => $current_master->{ping_interval},
+      ssh_user               => $current_master->{ssh_user},
+      ssh_host               => $current_master->{ssh_host},
+      ssh_ip                 => $current_master->{ssh_ip},
+      ssh_port               => $current_master->{ssh_port},
+      ssh_connection_timeout => $current_master->{ssh_connection_timeout},
+      ssh_check_command      => $ssh_check_command,
+      status_handler         => $_status_handler,
+      logger                 => $log,
+      logfile                => $g_logfile,
+      workdir                => $g_workdir,
+      ping_type              => $current_master->{ping_type},
     );
     $log->info(
       sprintf( "Set master ping interval %d seconds.",
@@ -632,6 +636,7 @@ sub main {
     'manager_log=s'           => \$g_logfile,
     'skip_ssh_check'          => \$g_skip_ssh_check,          # for testing
     'skip_check_ssh'          => \$g_skip_ssh_check,
+    'ignore_fail_on_start'    => \$g_ignore_fail_on_start,
   );
   setpgrp( 0, $$ ) unless ($g_interactive);
 
