@@ -226,8 +226,8 @@ sub identify_new_master {
   my $orig_master = shift;
   $_server_manager->set_latest_slaves( $_server_manager->{alive_slaves} );
   my $new_master =
-    $_server_manager->select_new_master( $g_new_master_host, $g_new_master_port,
-    0 );
+    $_server_manager->select_new_master( $g_new_master_host,
+    $g_new_master_port, 0 );
   unless ($new_master) {
     $log->error("Failed to get new master!");
     croak;
@@ -253,7 +253,9 @@ sub identify_new_master {
   }
   $log->info(" ok.");
 
-  check_filter( $orig_master, $new_master );
+  if ( $orig_master->{check_repl_filter} ) {
+    check_filter( $orig_master, $new_master );
+  }
 
   my @threads = $new_master->get_running_threads($g_running_seconds_limit);
   if ( $#threads >= 0 ) {
@@ -282,7 +284,7 @@ sub reject_update($$) {
   $log->info();
   if ( $new_master->{master_ip_online_change_script} ) {
     my $command =
-"$orig_master->{master_ip_online_change_script} --command=stop --orig_master_host=$orig_master->{hostname} --orig_master_ip=$orig_master->{ip} --orig_master_port=$orig_master->{port} --new_master_host=$new_master->{hostname} --new_master_ip=$new_master->{ip} --new_master_port=$new_master->{port}";
+"$orig_master->{master_ip_online_change_script} --command=stop --orig_master_host=$orig_master->{hostname} --orig_master_ip=$orig_master->{ip} --orig_master_port=$orig_master->{port} --orig_master_user=$orig_master->{escaped_user} --orig_master_password=$orig_master->{escaped_password} --new_master_host=$new_master->{hostname} --new_master_ip=$new_master->{ip} --new_master_port=$new_master->{port} --new_master_user=$new_master->{escaped_user} --new_master_password=$new_master->{escaped_password}";
     $command .= $orig_master->get_ssh_args_if( 1, "orig", 1 );
     $command .= $new_master->get_ssh_args_if( 2, "new", 1 );
     $log->info(
@@ -391,7 +393,7 @@ sub switch_master($$$$) {
   # Allow write access on the new master
   if ( $new_master->{master_ip_online_change_script} ) {
     my $command =
-"$new_master->{master_ip_online_change_script} --command=start --orig_master_host=$orig_master->{hostname} --orig_master_ip=$orig_master->{ip} --orig_master_port=$orig_master->{port} --new_master_host=$new_master->{hostname} --new_master_ip=$new_master->{ip} --new_master_port=$new_master->{port}";
+"$new_master->{master_ip_online_change_script} --command=start --orig_master_host=$orig_master->{hostname} --orig_master_ip=$orig_master->{ip} --orig_master_port=$orig_master->{port} --orig_master_user=$orig_master->{escaped_user} --orig_master_password=$orig_master->{escaped_password} --new_master_host=$new_master->{hostname} --new_master_ip=$new_master->{ip} --new_master_port=$new_master->{port} --new_master_user=$new_master->{escaped_user} --new_master_password=$new_master->{escaped_password}";
     $command .= $orig_master->get_ssh_args_if( 1, "orig", 1 );
     $command .= $new_master->get_ssh_args_if( 2, "new", 1 );
     $log->info(
@@ -566,7 +568,7 @@ sub switch_slaves($$$$$$) {
   if ( $ret eq '0' ) {
     $log->info("All new slave servers switched successfully.");
     $log->info();
-    $log->info("* Phase 5: New master cleanup phease..");
+    $log->info("* Phase 5: New master cleanup phase..");
     $log->info();
     if ( $new_master->{skip_reset_slave} ) {
       $log->info("Skipping RESET SLAVE on the new master.");
