@@ -354,8 +354,9 @@ sub check_set_ssh_status {
   if ( !$self->{dead} ) {
     if (
       MHA::HealthCheck::ssh_check_simple(
-        $self->{ssh_user}, $self->{ssh_host}, $self->{ssh_ip},
-        $self->{ssh_port}, $self->{logger},   5
+        $self->{ssh_user}, $self->{ssh_host},
+        $self->{ssh_ip},   $self->{ssh_port},
+        $self->{logger},   $self->{ssh_connection_timeout}
       )
       || MHA::ManagerUtil::check_node_version_nodie(
         $log,            $self->{ssh_user}, $self->{ssh_host},
@@ -541,7 +542,7 @@ sub check_binlog_stop {
   my $log  = $self->{logger};
   $log->info("Checking binlog writes are stopped or not..");
   my ( $file, $pos ) = $self->get_binlog_position();
-  sleep 1;
+  sleep(0.2);
   my ( $file2, $pos2 ) = $self->get_binlog_position();
   if ( ( $file2 ne $file ) || ( $pos != $pos2 ) ) {
     $log->error(
@@ -573,8 +574,7 @@ sub reconnect($) {
   my $self      = shift;
   my $conn_lost = 0;
   eval {
-    if ( !$self->{dbh}->ping() )
-    {
+    if ( !$self->{dbh}->ping() ) {
       die;
     }
   };
